"""
WelcomeScreen: A simple library providing a customizable welcome screen fading over an LCD 
Copyright (C) 2024  Benjamin Burkhardt

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import time


class WelcomeScreen:
    def __init__(self, lcd):
        self.lcd = lcd
        self.columns = self.lcd.num_columns
        self.lines = self.lcd.num_lines

    def show(self, cycles=1):  # loops says how often the Starting text goes through
        if cycles < 1: cycles = 1
        padding = " " * self.columns  # as much spaces as padding as one display line is long
        padding_hyphen = "-" * self.columns  # as much hyphens as padding as one display line is long
        starting_str = "Starting..."
        started_str = "Started!".center(self.columns)
        
        # mechanism for centering on a 4*20 display
        y_offset = 0
        if self.lines == 4:
            y_offset = 1
            # also clear the top and bottom with ----
            self.lcd.move_to(0,0)
            self.lcd.putstr(padding_hyphen)
            self.lcd.move_to(0,4)
            self.lcd.putstr(padding_hyphen)
        
        for i in range(cycles):
            line1 = padding + starting_str + padding
            line2 = "The Program!".center(self.columns)
            for i in range(self.columns + len(starting_str)):
                self.lcd.move_to(0,y_offset)
                self.lcd.putstr(line1[0:self.columns])
                self.lcd.move_to(0,y_offset+1)
                self.lcd.putstr(line2[0:self.columns])
                line1 = line1[1:]
        
        self.lcd.move_to(0,y_offset)
        self.lcd.putstr(started_str)
            
        # now fade down
        if self.lines == 4:
            current_display = padding_hyphen + started_str + "The Program!".center(self.columns) + padding_hyphen
        else:
            current_display = started_str + "The Program!".center(self.columns)
        time.sleep(1)
        self.lcd.move_to(0,y_offset)
        self.lcd.putstr(padding + started_str)
        time.sleep(0.1)
        self.lcd.clear()
        time.sleep(0.3)

